/*!
 * @file glgui_style.h
 * @brief Definition of ...
*/

#ifndef _GLGUI_STYLE_H
#define _GLGUI_STYLE_H

// FORWARD DECLARATION

#include "font.h"
#include "texture.h"
#include "color.h"

namespace OrxGui
{
  //! A class for Defining Styles to the opengl-gui.
  class GLGuiStyle
  {
    //! An enumerator that defines the different states Widgets may be in.
    typedef enum {
      Normal,           //!< Normal state of the GUI's Widgets.
      Active,           //!< If the widget is Active.
      Selected,         //!< If the Widget is Selected.
      Insensitive       //!< If the Widget is insensitive.
    } State;

  public:
    GLGuiStyle();
    virtual ~GLGuiStyle();


  private:

    float             _borderLeft;           //!< The Distance to the left Border of the widget, before any internal Element starts.
    float             _borderRight;          //!< The Distance to the right Border of the widget, before any internal Element starts.
    float             _borderTop;            //!< The Distance to the top Border of the widget, before any internal Element starts
    float             _borderBottom;         //!< The Distance to the bottom Border of the widget, before any internal Element starts

    Font*             _font;                 //!< The Font used in the current Widget.
    float             _textSize;             //!< The TextSize of the Widget.
    float             _textColor;            //!< The TextColor of the Widget.

    float             _backgroundColor;      //!< The BackgroundColor of the Widget.
    Texture           _backgorundTexture;    //!< The BackgroundTexture of the Widget.

    float             _foregroundColor;      //!< The foregroundColor of the Widget.
    Texture           _foregorundTexture;    //!< The ForegroundTexture of the Widget

    bool              _animated;             //!< If the Widget is animated (Texture might be an AnimatedTexture.)
    bool              _animatedStateChanges; //!< If the Transitions between States are Animated automatically.
  };
}
#endif /* _GLGUI_STYLE_H */
